/*
 * LED color setting list
 *  for Wi-Fi view & select
 */
package jp.gr.java_conf.j_sota.wifiviewandselect;

import java.util.ArrayList;

import android.content.Context;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;
import android.graphics.Color;
import android.os.Bundle;
import android.os.Parcel;
import android.os.Parcelable;
import android.preference.PreferenceManager;

//Implement Parcelable since this class is transferred with Bundle
public class LedColorList implements Parcelable {
	
	private ArrayList<LedColorListData> mLedColorList;

	/**
	 * Return a array body
	 * @return		Configured Wi-Fi list
	 */
	public ArrayList<LedColorListData> getArray() {
		return mLedColorList;
	}

	/**
	 * Add a LED color data to list
	 * @param ssid		SSID
	 * @param ledColor	LED color
	 * @param used		Used flag
	 */
	public void add(String ssid, int ledColor, boolean used) {
		LedColorListData data = new LedColorListData();
		data.ssid = ssid;
		data.ledColor = ledColor;
		data.used = used;
		mLedColorList.add(data);
	}

	/**
	 * Remove LED color data from position
	 * @param position	Position
	 */
	public void remove(int position) {
		mLedColorList.remove(position);
	}

	/**
	 * Get SSID from position
	 * @param position	Position
	 * @return String	SSID
	 */
	public String getSsid(int position) {
		return mLedColorList.get(position).ssid;
	}

	/**
	 * Return LED color from position
	 * @param position	Position
	 * @return int		LED color
	 */
	public int getLedColor(int position) {
		return mLedColorList.get(position).ledColor;
	}

	/**
	 * Return LED color from SSID or network ID
	 * If specified SSID is in the list, get color from list.
	 * If not, get default color from network ID
	 * @param ssid			SSID
	 * @param networkId		Network ID
	 * @param context		Context
	 * @return int 		LED Color
	 */
	public int getLedColorFromSsid(String ssid, int networkId, Context context) {
		// Search SSID from list and get LED color
		int color = Color.DKGRAY;
		boolean found = false;
		for (int i = 0; i < mLedColorList.size(); i++) {
			if (mLedColorList.get(i).ssid.equals(ssid)) {
				color = mLedColorList.get(i).ledColor;
				found = true;
				break;
			}
		}
		if (!found) {
			// Get default color if SSID is not in the list
			final int defaultColorList[] = { Color.BLUE, Color.CYAN, Color.GREEN, Color.MAGENTA, Color.RED, Color.YELLOW };
			if ((networkId >= 0) && (networkId < defaultColorList.length)) {
				color = defaultColorList[networkId];
			}
			add(ssid, color, true);
			
			// Save SSID and it's color to default preference
			SharedPreferences preference = PreferenceManager.getDefaultSharedPreferences(context);
			int index = preference.getInt(context.getString(R.string.key_led_setting), 0);
			Editor editor = preference.edit();
			String ssidKey = context.getString(R.string.key_led_setting_ssid) + index;
			String colorKey = context.getString(R.string.key_led_setting_color) + index;
			editor.putString(ssidKey, ssid);
			editor.putInt(colorKey, color);
			index += 1;
			editor.putInt(context.getString(R.string.key_led_setting), index);
			editor.commit();
		}
		return color;
	}

	/**
	 * Set LED color to position
	 * @param position	Position
	 * @param ledColor	LED color
	 */
	public void setLedColor(int position, int ledColor) {
		LedColorListData data = mLedColorList.get(position);
		data.ledColor = ledColor;
	}

	/**
	 * Return used flag from position
	 * @param position	Position
	 * @return boolean	Used flag
	 */
	public boolean getUsed(int position) {
		return mLedColorList.get(position).used;
	}

	/**
	 * Set used flag to position
	 * @param position	Position
	 * @param used		Used flag
	 */
	public void setUsed(int position, boolean used) {
		LedColorListData data = mLedColorList.get(position);
		data.used = used;
	}

	/**
	 * Return a list data size
	 * @return int		list data size
	 */
	public int size() {
		return mLedColorList.size();
	}

	public static final Parcelable.Creator<LedColorList> CREATOR =
			new Parcelable.Creator<LedColorList>() {

		/**
		 * Create list from parcel
		 * @param in	parcel data
		 */
		public LedColorList createFromParcel(Parcel in) {
			return new LedColorList(in);
		}

		/**
		 * Create a new array
		 * @param size		size
		 * @return LedColorList[] 	array
		 */
		public LedColorList[] newArray(int size) {
			return new LedColorList[size];
		}
	};

	/**
	 * Constructor
	 * No initial data
	 */
	public LedColorList() {
		mLedColorList = new ArrayList<LedColorListData>();
	}

	/**
	 * Constructor
	 * read data from parcel
	 * @param in	Parcel data
	 */
	private LedColorList(Parcel in) {
		Bundle b = in.readBundle(LedColorListData.class.getClassLoader());
		mLedColorList = b.getParcelableArrayList("items");
	}

	/**
	 * Write to Parcel
	 * @param dest
	 * @param flags
	 */
	public void writeToParcel(Parcel dest, int flags) {
		Bundle b = new Bundle();
		b.putParcelableArrayList("items", mLedColorList);
		dest.writeBundle(b);
	}

	/**
	 * Describe contents
	 * @return always 0
	 */
	public int describeContents() {
		return 0;
	}
}
